==> gulp-ts-foundation-0.0.6.tgz: package/src/registry.ts <==
import {Gulp} from 'gulp';
import * as assert from 'assert';
import {TaskContext, ContextConfig} from './taskContext';
import * as DefaultRegistry from 'undertaker-registry';

import {Cleaner} from './tasks/clean';
import {Statics} from './tasks/statics';
import {TsLinter} from './tasks/tsLint';
import {ServerCompiler} from './tasks/compiler';
import {ServerTest} from './tasks/serverTest';
import {Server} from './tasks/server';
import {WebpackDevServer} from './tasks/webpackDevServer';

export class Registry extends DefaultRegistry {

  protected readonly context: TaskContext;

  constructor(config: ContextConfig) {
    super();
    assert(typeof config.rootPath === 'string', 'rootPath must be defined in Registry options');
    this.context = new TaskContext(config);
  }

  public init(gulp: Gulp) {
    super.init(gulp);

    const {task, parallel, series} = gulp;

    const server = new Server(this.context);
    const cleaner = new Cleaner(this.context);
    const statics = new Statics(this.context);
    const tslint = new TsLinter(this.context);
    const compiler = new ServerCompiler(this.context);
    const serverTest = new ServerTest(this.context, server);
    const webpackDevServer = new WebpackDevServer(this.context);

    // lazily get task dependencies so overridden task definitions are as part of these chains
    const $ = taskName => done => task(taskName)(done);

    task('clean:client', cleaner.cleanClient);
    task('clean:server', cleaner.cleanServer);
    task('clean', parallel($('clean:client'), $('clean:server')));

    task('statics:build', statics.build);

    task('tslint:tasks', tslint.lintTasks);
    task('tslint:server', tslint.lintServer);
    task('tslint:client', tslint.lintClient);
    task('tslint', parallel('tslint:client', 'tslint:client'));

    task('client:prebuild', parallel(
      'tslint:client',
      series($('clean:client'), $('statics:build'))
    ));
    task('client:build', series($('client:prebuild')/* webpack here */));
    task('client:devServer', series($('client:prebuild'), webpackDevServer.serve));

    task('server:precompile', done => done);
    task('server:compile', series($('server:precompile'), compiler.compile));

    task('server:test:single', series(
      $('server:compile'),
      serverTest.single
    ));

    task('server:test', series(
      parallel($('server:test:single'), compiler.watch),
      serverTest.continuous
    ));

    task('server:run', parallel(
      'tslint:server',
      parallel(
        compiler.watch,
        serverTest.applyHooks
      ),
      series(
        $('clean:server'),
        $('server:compile'),
        server.serve
      )
    ));

    task('dev', parallel($('client:devServer'), $('server:run')));

    task('default', $('dev'));
  }
}

==> gulp-ts-foundation-0.0.7.tgz: package/src/registry.ts <==
import {Gulp} from 'gulp';
import * as assert from 'assert';
import * as DefaultRegistry from 'undertaker-registry';
import * as asyncDone from 'async-done';

import {TaskContext, ContextConfig} from './taskContext';
import {TaskTracker} from './taskTracker';

import {Cleaner} from './tasks/clean';
import {Statics} from './tasks/statics';
import {TsLinter} from './tasks/tsLint';
import {ServerCompiler} from './tasks/compiler';
import {ServerTest} from './tasks/serverTest';
import {Server} from './tasks/server';
import {WebpackDevServer} from './tasks/webpackDevServer';


export class Registry extends DefaultRegistry {

  protected readonly context: TaskContext;

  constructor(config: ContextConfig) {
    super();
    assert(typeof config.rootPath === 'string', 'rootPath must be defined in Registry options');
    this.context = new TaskContext(config);
  }

  public init(gulp: Gulp) {
    super.init(gulp);

    const {task, parallel, series} = gulp;

    /* tslint:disable-next-line */
    const tracker = new TaskTracker(gulp);

    const server = new Server(this.context);
    const cleaner = new Cleaner(this.context);
    const statics = new Statics(this.context);
    const tslint = new TsLinter(this.context);
    const compiler = new ServerCompiler(this.context);
    const serverTest = new ServerTest(this.context, server);
    const webpackDevServer = new WebpackDevServer(this.context);

    // lazily get task dependencies so overridden task definitions are as part of these chains
    const inject = taskName => {
      const fn = done => asyncDone(task(taskName), done);
      (fn as any).displayName = `[injected] ${taskName}`;

      return fn;
    };

    task('clean:client', cleaner.cleanClient);
    task('clean:server', cleaner.cleanServer);

    task('clean', parallel(
      inject('clean:client'),
      inject('clean:server')));

    task('statics:build', statics.build);

    task('tslint:tasks', tslint.lintTasks);
    task('tslint:server', tslint.lintServer);
    task('tslint:client', tslint.lintClient);

    task('tslint', parallel(
      inject('tslint:client'),
      inject('tslint:server')));

    task('client:prebuild', parallel(
      inject('tslint:client'),
      series(
        inject('clean:client'),
        inject('statics:build'))
    ));

    task('client:build', series(
      inject('client:prebuild')
      /* TODO: add webpack here */));

    task('client:devServer', series(
      inject('client:prebuild'),
      webpackDevServer.serve));

    task('server:precompile', done => done());

    task('server:compile', series(
      inject('server:precompile'),
      compiler.compile));

    task('server:test:single', series(
      inject('server:compile'),
      serverTest.single
    ));

    task('server:test', series(
      parallel(
        inject('server:test:single'),
        compiler.watch),
      serverTest.continuous
    ));

    task('server:run', parallel(
      inject('tslint:server'),
      parallel(
        compiler.watch,
        serverTest.applyHooks
      ),
      series(
        inject('clean:server'),
        inject('server:compile'),
        server.serve
      )
    ));

    task('dev', parallel(
      inject('client:devServer'),
      inject('server:run')));

    task('default', inject('dev'));
  }
}
